==> humhub-1.17.5.zip: humhub-1.17.5/protected/humhub/modules/user/messages/fr/account.php <==
<?php
return [
  '<strong>Account</strong> Settings' => 'Réglages du <strong>Compte</strong>',
  '<strong>Confirm</strong></strong> your new email address' => '<strong>Confirmez</strong> votre nouvelle adresse e-mail',
  '<strong>Permissions</strong>' => '<strong>Autorisations</strong>',
  '<strong>Your</strong> Account' => '<strong>Votre</strong> compte',
  '<strong>Your</strong> profile' => '<strong>Votre</strong> profil',
  'Add tags to your profile describing you and highlighting your skills and interests. Your tags will be displayed in your profile and in the \'People\' directory.' => 'Ajoutez des mots-clés vous décrivant et présentant vos compétences et vos centres d’intérêts. Vos mots-clés seront affichés dans votre profil et dans l’annuaire des membres.',
  'All your personal data will be irrevocably deleted.' => 'Toutes vos données personnelles seront irrémédiablement supprimées.',
  'Are you sure that you want to delete your account?' => 'Êtes-vous certain de vouloir supprimer votre compte ?',
  'Blocked users' => 'Utilisateurs bloqués',
  'Changing the username can make some links unusable, for example old links to the profile.' => 'La modification du nom d\'utilisateur peut entraîner la rupture de liens (par exemple, un lien vers l\'ancien profil).',
  'Confirm' => 'Confirmer',
  'Current password' => 'Mot de passe actuel',
  'Define basic settings for your profile. You can add tags that fit you, choose the language and your time zone and block impolite users.' => 'Définissez les réglages de base de votre profil. Vous pouvez ajouter des mots-clés vous décrivant, choisir votre langue et votre fuseau horaire, et bloquer les utilisateurs et utilisatrices impoli·es.',
  'Delete account' => 'Supprimer le compte',
  'Do you really want to delete your icon image?' => 'Souhaitez-vous vraiment supprimer votre icône ?',
  'Do you really want to delete your logo image?' => 'Souhaitez-vous vraiment supprimer votre logo ?',
  'E-Mail' => 'e-mail',
  'E-Mail change' => 'Changement d\'adresse e-mail',
  'Enter your password to continue' => 'Indiquez votre mot de passe pour continuer',
  'General' => 'Général',
  'Hello' => 'Bonjour',
  'Here you can edit your general profile data, which is visible in the about page of your profile.' => 'Vous pouvez modifier ici les données de votre profil, visibles dans votre page "À propos"',
  'Hide introduction tour panel on dashboard' => 'Masquer le panneau "premiers pas" sur la vue d\'ensemble',
  'Hide my online status' => 'Masquer mon statut de connexion',
  'Invalid link! Please make sure that you entered the entire url.' => 'Lien invalide. Vérifiez que vous avez indiqué l\'URL complète.',
  'Language' => 'Langue',
  'Markdown Editor Mode' => 'Mode d’édition Markdown',
  'Modules' => 'Modules',
  'New E-Mail address' => 'Nouvelle adresse e-mail',
  'New User name' => 'Nouveau nom d\'utilisateur',
  'Not registered users' => 'Visiteurs',
  'Notifications' => 'Notifications',
  'Other users' => 'Autres',
  'Password Recovery' => 'Récupération de mot de passe',
  'Password recovery can only be initiated once every 10 minutes.' => 'La récupération du mot de passe ne peut être lancée qu\'une fois toutes les 10 minutes.',
  'Password recovery disabled. Please contact your system administrator.' => 'La récupération du mot de passe est désactivée. Veuillez contacter votre administrateur système.',
  'Permissions' => 'Permissions',
  'Plain' => 'Simple',
  'Profile' => 'Profil',
  'Profile Tags' => 'Mots-clés du profil',
  'Profile visibility' => 'Visibilité du profil',
  'Registered users only' => 'Utilisateurs enregistrés uniquement',
  'Rich Text' => 'Enrichi (Rich Text)',
  'Save' => 'Enregistrer',
  'Save profile' => 'Enregistrer le profil',
  'The entered e-mail address is already in use by another user.' => 'L\'adresse e-mail indiquée est déjà utilisée par une autre personne.',
  'These settings allow you to determine which permissions you want to grant visitors of your own individual profile. Each user can freely adjust the settings for his or her own profile.' => 'Ces paramètres permettent de définir quelles autorisations vous désirez accorder aux visiteurs qui accèdent à votre profil. Chaque utilisateur·rice peut modifier librement ces paramètres sur son profil.',
  'TimeZone' => 'Fuseau horaire',
  'Username has been changed' => 'Votre nom d\'utilisateur a été modifié',
  'Users' => 'Utilisateurs',
  'Visible for all (also unregistered users)' => 'Visible par tous (visiteurs également)',
  'We´ve just sent an confirmation e-mail to your new address. <br /> Please follow the instructions inside.' => 'Nous venons juste de vous envoyer un message vers votre nouvelle adresse e-mail. <br /> Merci de suivre les instructions qu\'il contient.',
  'You are currently the owner of following spaces:' => 'Vous êtes actuellement le propriétaire des espaces suivants :',
  'You cannot use this username.' => 'Vous ne pouvez pas utiliser ce nom d’utilisateur.',
  'You have requested to change your e-mail address.<br>Your new e-mail address is {newemail}.<br><br>To confirm your new e-mail address please click on the button below.' => 'Vous avez demandé un changement d\'adresse e-mail.<br />Votre nouvelle adresse est {newemail}.<br /><br />Pour confirmer cette nouvelle adresse, cliquez sur le bouton ci-dessous.',
  'You have successfully changed your username.<br>Your new username is {newUsername}.' => 'Votre nom d\'utilisateur a été changé.<br />Votre nouveau nom d\'utilisateur est {newUsername}.',
  'You must transfer ownership or delete these spaces before you can delete your account.' => 'Vous devez transférer l\'appartenance de ces espaces ou supprimer ceux-ci avant de pouvoir supprimer votre compte.',
  'Your account cannot be deleted!' => 'Votre compte ne peut être supprimé.',
  'Your current E-mail address is <b>{email}</b>. You can change your current E-mail address here.' => 'Votre adresse e-mail actuelle est <b>{email}</b>. Vous pouvez modifier votre adresse e-mail ici.',
  'Your current password can be changed here.' => 'Votre mot de passe peut être modifié ici.',
  'Your current username is <b>{username}</b>. You can change your current username here.' => 'Votre nom d\'utilisateur actuel est <b>{username}</b>. Vous pouvez changer votre nom d\'utilisateur ici.',
  'Your e-mail address has been successfully changed to {email}.' => 'Votre adresse e-mail vient d\'être modifiée vers {email}',
  'Your friends' => 'Mes amis',
  'Your password has been successfully changed!' => 'Votre mot de passe a été changé avec succès.',
  'Your username has been changed' => 'Votre nom d\'utilisateur a été modifié',
  'Your username has been successfully changed. <br> We´ve just sent an e-mail to you with new information.' => 'Votre nom d\'utilisateur a été changé.<br />Vous recevrez un e-mail contenant les nouvelles informations.',
];

==> humhub-1.18.0.zip: humhub-1.18.0/protected/humhub/modules/user/messages/fr/account.php <==
<?php
return [
  '<strong>Account</strong> Settings' => 'Réglages du <strong>Compte</strong>',
  '<strong>Confirm</strong></strong> your new email address' => '<strong>Confirmez</strong> votre nouvelle adresse e-mail',
  '<strong>Permissions</strong>' => '<strong>Autorisations</strong>',
  '<strong>Your</strong> Account' => '<strong>Votre</strong> compte',
  '<strong>Your</strong> profile' => '<strong>Votre</strong> profil',
  'Add tags to your profile describing you and highlighting your skills and interests. Your tags will be displayed in your profile and in the \'People\' directory.' => 'Ajoutez des mots-clés vous décrivant et présentant vos compétences et vos centres d’intérêts. Vos mots-clés seront affichés dans votre profil et dans l’annuaire des membres.',
  'All your personal data will be irrevocably deleted.' => 'Toutes vos données personnelles seront irrémédiablement supprimées.',
  'Are you sure that you want to delete your account?' => 'Êtes-vous certain de vouloir supprimer votre compte ?',
  'Blocked users' => 'Utilisateurs bloqués',
  'Changing the username can make some links unusable, for example old links to the profile.' => 'La modification du nom d\'utilisateur peut entraîner la rupture de liens (par exemple, un lien vers l\'ancien profil).',
  'Confirm' => 'Confirmer',
  'Current password' => 'Mot de passe actuel',
  'Define basic settings for your profile. You can add tags that fit you, choose the language and your time zone and block impolite users.' => 'Définissez les réglages de base de votre profil. Vous pouvez ajouter des mots-clés vous décrivant, choisir votre langue et votre fuseau horaire, et bloquer les utilisateurs et utilisatrices impoli·es.',
  'Delete account' => 'Supprimer le compte',
  'Do you really want to delete your icon image?' => 'Souhaitez-vous vraiment supprimer votre icône ?',
  'Do you really want to delete your login background image?' => 'Voulez-vous vraiment supprimer votre image d’arrière-plan de connexion ?',
  'Do you really want to delete your logo image?' => 'Souhaitez-vous vraiment supprimer votre logo ?',
  'Do you really want to delete your mail header image?' => 'Voulez-vous vraiment supprimer l\'image d\'en-tête de votre e-mail ?',
  'E-Mail' => 'e-mail',
  'E-Mail change' => 'Changement d\'adresse e-mail',
  'Enter your password to continue' => 'Indiquez votre mot de passe pour continuer',
  'General' => 'Général',
  'Hello' => 'Bonjour',
  'Here you can edit your general profile data, which is visible in the about page of your profile.' => 'Vous pouvez modifier ici les données de votre profil, visibles dans votre page "À propos"',
  'Hide introduction tour panel on dashboard' => 'Masquer le panneau "premiers pas" sur la vue d\'ensemble',
  'Hide my online status' => 'Masquer mon statut de connexion',
  'Invalid link! Please make sure that you entered the entire url.' => 'Lien invalide. Vérifiez que vous avez indiqué l\'URL complète.',
  'Language' => 'Langue',
  'Markdown Editor Mode' => 'Mode d’édition Markdown',
  'Modules' => 'Modules',
  'New E-Mail address' => 'Nouvelle adresse e-mail',
  'New User name' => 'Nouveau nom d\'utilisateur',
  'Not registered users' => 'Visiteurs',
  'Notifications' => 'Notifications',
  'Other users' => 'Autres',
  'Password Recovery' => 'Récupération de mot de passe',
  'Password recovery can only be initiated once every 10 minutes.' => 'La récupération du mot de passe ne peut être lancée qu\'une fois toutes les 10 minutes.',
  'Password recovery disabled. Please contact your system administrator.' => 'La récupération du mot de passe est désactivée. Veuillez contacter votre administrateur système.',
  'Permissions' => 'Permissions',
  'Plain' => 'Simple',
  'Profile' => 'Profil',
  'Profile Tags' => 'Mots-clés du profil',
  'Profile visibility' => 'Visibilité du profil',
  'Registered users only' => 'Utilisateurs enregistrés uniquement',
  'Rich Text' => 'Enrichi (Rich Text)',
  'Save' => 'Enregistrer',
  'Save profile' => 'Enregistrer le profil',
  'The entered e-mail address is already in use by another user.' => 'L\'adresse e-mail indiquée est déjà utilisée par une autre personne.',
  'These settings allow you to determine which permissions you want to grant visitors of your own individual profile. Each user can freely adjust the settings for his or her own profile.' => 'Ces paramètres permettent de définir quelles autorisations vous désirez accorder aux visiteurs qui accèdent à votre profil. Chaque utilisateur·rice peut modifier librement ces paramètres sur son profil.',
  'TimeZone' => 'Fuseau horaire',
  'Username has been changed' => 'Votre nom d\'utilisateur a été modifié',
  'Users' => 'Utilisateurs',
  'Visible for all (also unregistered users)' => 'Visible par tous (visiteurs également)',
  'We´ve just sent an confirmation e-mail to your new address. <br /> Please follow the instructions inside.' => 'Nous venons juste de vous envoyer un message vers votre nouvelle adresse e-mail. <br /> Merci de suivre les instructions qu\'il contient.',
  'You are currently the owner of following spaces:' => 'Vous êtes actuellement le propriétaire des espaces suivants :',
  'You cannot use this username.' => 'Vous ne pouvez pas utiliser ce nom d’utilisateur.',
  'You have requested to change your e-mail address.<br>Your new e-mail address is {newemail}.<br><br>To confirm your new e-mail address please click on the button below.' => 'Vous avez demandé un changement d\'adresse e-mail.<br />Votre nouvelle adresse est {newemail}.<br /><br />Pour confirmer cette nouvelle adresse, cliquez sur le bouton ci-dessous.',
  'You have successfully changed your username.<br>Your new username is {newUsername}.' => 'Votre nom d\'utilisateur a été changé.<br />Votre nouveau nom d\'utilisateur est {newUsername}.',
  'You must transfer ownership or delete these spaces before you can delete your account.' => 'Vous devez transférer l\'appartenance de ces espaces ou supprimer ceux-ci avant de pouvoir supprimer votre compte.',
  'Your account cannot be deleted!' => 'Votre compte ne peut être supprimé.',
  'Your current E-mail address is <b>{email}</b>. You can change your current E-mail address here.' => 'Votre adresse e-mail actuelle est <b>{email}</b>. Vous pouvez modifier votre adresse e-mail ici.',
  'Your current password can be changed here.' => 'Votre mot de passe peut être modifié ici.',
  'Your current username is <b>{username}</b>. You can change your current username here.' => 'Votre nom d\'utilisateur actuel est <b>{username}</b>. Vous pouvez changer votre nom d\'utilisateur ici.',
  'Your e-mail address has been successfully changed to {email}.' => 'Votre adresse e-mail vient d\'être modifiée vers {email}',
  'Your friends' => 'Mes amis',
  'Your password has been successfully changed!' => 'Votre mot de passe a été changé avec succès.',
  'Your username has been changed' => 'Votre nom d\'utilisateur a été modifié',
  'Your username has been successfully changed. <br> We´ve just sent an e-mail to you with new information.' => 'Votre nom d\'utilisateur a été changé.<br />Vous recevrez un e-mail contenant les nouvelles informations.',
];
